@@ -1,20 +1,12 @@
 package Data::TUID;
+BEGIN {
+  $Data::TUID::VERSION = '0.0120';
+}
+# ABSTRACT: A smaller and more communicable pseudo-UUID
 
 use warnings;
 use strict;
 
-=head1 NAME
-
-Data::TUID - A smaller and more communicable pseudo-UUID
-
-=head1 VERSION
-
-Version 0.011
-
-=cut
-
-our $VERSION = '0.011';
-
 =head1 SYNOPSIS
 
     use Data::TUID
@@ -94,7 +86,16 @@ L<http://www.crockford.com/wrmg/base32.html>
 use vars qw/@ISA @EXPORT/; @ISA = qw/Exporter/; @EXPORT = qw/tuid/;
 
 use Encode::Base32::Crockford qw/base32_encode/;
-use Data::UUID::LibUUID qw/new_uuid_binary uuid_to_binary/;
+
+use Data::TUID::BestUUID;
+
+sub new_uuid {
+    return Data::TUID::BestUUID->new_uuid( @_ );
+}
+
+sub uuid_to_canonical {
+    return Data::TUID::BestUUID->uuid_to_canonical( @_ );
+}
 
 sub tuid {
     shift if @_ && $_[0] eq __PACKAGE__;
@@ -106,10 +107,18 @@ sub tuid {
         %given = @_;
     }
 
-    my $uuid = $given{uuid} || new_uuid_binary;
-    $uuid = uuid_to_binary $uuid;
+    my $uuid = $given{uuid} || new_uuid;
+    $uuid = uuid_to_canonical( $uuid );
 
-    my @tuid = map { lc base32_encode $_ } unpack 'L*', new_uuid_binary;
+    my @tuid;
+    {
+        my $uuid = $uuid;
+        $uuid =~ s/-//g;
+        my @hex = unpack( 'A8 A8 A8 A8', $uuid );
+        my @value = map { hex $_ } @hex;
+        my @base32 = map { base32_encode $_ } @value;
+        @tuid = @base32;
+    }
 
     my $all;
     my $size = $given{size};
@@ -131,60 +140,8 @@ sub tuid {
     return $tuid;
 }
 
-=head1 AUTHOR
-
-Robert Krimen, C<< <rkrimen at cpan.org> >>
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-data-tuid at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Data-TUID>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Data::TUID
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Data-TUID>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Data-TUID>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Data-TUID>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Data-TUID/>
-
-=back
-
-
 =head1 ACKNOWLEDGEMENTS
 
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2009 Robert Krimen, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-
 =cut
 
-1; # End of Data::TUID
+1;
